summaryrefslogtreecommitdiff
path: root/html
diff options
context:
space:
mode:
Diffstat (limited to 'html')
-rw-r--r--html/app/config/app_constants.php39
-rw-r--r--html/app/controllers/Auth.php26
2 files changed, 57 insertions, 8 deletions
diff --git a/html/app/config/app_constants.php b/html/app/config/app_constants.php
index a89cc6a..4ddf7ac 100644
--- a/html/app/config/app_constants.php
+++ b/html/app/config/app_constants.php
@@ -1,11 +1,40 @@
<?php
+// Contents
+// Central Defaults (name)
+// Default Values (user-privileges and user-roles)
+
+
+// read ini file id exist
+// --- -- -- - - -
+if (file_exists("../core/auth/.env")) {
+ $env = parse_ini_file("../core/auth/.env");
+}
+
+
// CENTRAL DEFAULTS ////////////////////////////////////////////////////////////
// -----------------------------------------------------------------------------
+// NOTE:
+// if .env file exists ... do not touch anything
+// else ... replace $env[*] values with your setup
+
+// WEB-APP name and url
+// --- -- -- - - -
define('SITE_TITLE', 'Classroom');
-define('NO_REPLY_EMAIL', 'noreply@roptron.gr');
-define('REPLY_TO_EMAIL', 'noreply@roptron.gr');
+define('SITE_URL', 'http://localhost');
+
+// email setup
+// --- -- -- - - -
+define('MAIL_MAILER', $env['MAIL_MAILER']);
+define('MAIL_HOST', $env['MAIL_HOST']);
+define('MAIL_PORT', $env['MAIL_PORT']);
+define('MAIL_USERNAME', $env['MAIL_USERNAME']);
+define('MAIL_PASSWORD', $env['MAIL_PASSWORD']);
+define('MAIL_ENCRYPTION', $env['MAIL_ENCRYPTION']);
+define('NO_REPLY_EMAIL', $env['NO_REPLY_EMAIL']);
+define('REPLY_TO_EMAIL', $env['REPLY_TO_EMAIL']);
+
// DEFAULT VALUES //////////////////////////////////////////////////////////////
@@ -13,15 +42,15 @@ define('REPLY_TO_EMAIL', 'noreply@roptron.gr');
// default privileges (for the subscribed user)
// (array of privilege aliases)
-// ---
+// --- -- -- - - -
define('DEFAULT_PRIVILEGES', [
'e.1', // economics, level 1
'p.1' // programming. level 1
]);
-
-
+// User Roles
+// --- -- -- - - -
define('READER', 1);
define('EDITOR', 2);
define('ADMIN', 3);
diff --git a/html/app/controllers/Auth.php b/html/app/controllers/Auth.php
index d0462e2..6c3eadc 100644
--- a/html/app/controllers/Auth.php
+++ b/html/app/controllers/Auth.php
@@ -127,11 +127,29 @@ class Auth {
private static function mail_activationCode($letter)
{
$mail = new PHPMailer();
+
+ // setup smpt
+ $mail->SMTPDebug = 2;
+ $mail->IsSMTP();
+ $mail->Host = MAIL_HOST;
+ $mail->SMPTAuth = true;
+ $mail->SMTPSecure = MAIL_ENCRYPTION;
+ $mail->Protocol = 'mail';
+
+ $mail->Mailer = MAIL_MAILER;
+ $mail->Port = MAIL_PORT;
+ $mail->Username = MAIL_USERNAME;
+ $mail->Password = MAIL_PASSWORD;
+
+ // setup format
$mail->CharSet = 'utf-8';
$mail->IsHTML(true);
- //It's important not to use the submitter's address as the from address as it's forgery,
- //which will cause your messages to fail SPF checks.
- //Use an address in your own domain as the from address, put the submitter's address in a reply-to
+
+ // setup THE mail
+ // --- -- -- - - -
+ // It's important not to use the submitter's address as the from address as it's forgery,
+ // which will cause your messages to fail SPF checks.
+ // Use an address in your own domain as the from address, put the submitter's address in a reply-to
$mail->setFrom(NO_REPLY_EMAIL, SITE_TITLE);
$mail->addAddress($letter['email'], $letter['name']);
$mail->addReplyTo(REPLY_TO_EMAIL, SITE_TITLE);
@@ -277,3 +295,5 @@ class Auth {
}
+// NOTE:
+// check: https://netcorecloud.com/tutorials/send-an-email-via-gmail-smtp-server-using-php/ \ No newline at end of file